Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(842)

Unified Diff: chrome/browser/ui/cocoa/profiles/avatar_button.h

Issue 2459073003: [Mac] Implement an active state for the avatar button (Closed)
Patch Set: Updated comment Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/profiles/avatar_button.h
diff --git a/chrome/browser/ui/cocoa/profiles/avatar_button.h b/chrome/browser/ui/cocoa/profiles/avatar_button.h
index 444110d5c23aba0d8034864e5b78bc701267e4ab..f6ab93acc41181517854467d0ee8aa8050ae445e 100644
--- a/chrome/browser/ui/cocoa/profiles/avatar_button.h
+++ b/chrome/browser/ui/cocoa/profiles/avatar_button.h
@@ -9,12 +9,17 @@
#import "ui/base/cocoa/hover_image_button.h"
// A subclass of HoverImageButton that sends a target-action on right click.
@interface AvatarButton : HoverImageButton {
@private
SEL rightAction_;
}
+// YES if the button is active. The button should only be active when the
+// avatar bubble is shown.
+@property(nonatomic, assign) BOOL isActive;
+
// Sets the action that will be called when this button is right clicked.
- (void)setRightAction:(SEL)selector;
« no previous file with comments | « chrome/browser/ui/cocoa/profiles/avatar_base_controller.h ('k') | chrome/browser/ui/cocoa/profiles/avatar_button.mm » ('j') | no next file with comments »

Powered by Google App Engine
@@ -9,12 +9,17 @@
#import "ui/base/cocoa/hover_image_button.h"
-// A subclass of HoverImageButton that sends a target-action on right click.
+// A subclass of HoverImageButton that sends a target-action on right click and
+// has an active state.
This is Rietveld 408576698